one-two-scrape
==============

[![PyPi Version](https://img.shields.io/pypi/v/one-two-scrape)](https://pypi.org/project/one-two-scrape/)
[![Supported Python Versions](https://img.shields.io/pypi/pyversions/one-two-scrape.svg)](https://pypi.org/project/one-two-scrape/)
[![License](https://img.shields.io/github/license/ssripilaipong/otscrape)](https://github.com/SSripilaipong/otscrape/blob/master/LICENSE.md)

A lightweight yet powerful scraping module. Well-designed for readability and reusability. 
Compatible with popular data science frameworks and modules (eg. pandas, Jupyter).
